# 🦋 blue-flie

🌀 `@flie` is an [`abcli`](https://github.com/kamangir/awesome-bash-cli) plugin for flying drones.

```bash
pip install blue-flie
```

|   |
| --- |
| [`blue-flie`](#) [![image](https://www.bitcraze.io/images/documentation/overview/system_overview.jpg)](#) starting off on a [Crazyflie 2.1+](https://www.bitcraze.io/products/crazyflie-2-1-plus/)... |

---

- https://www.bitcraze.io/products/crazyflie-2-1-plus/
- https://www.bitcraze.io/products/crazyradio-2-0/
- https://www.bitcraze.io/documentation/system/
- https://www.bitcraze.io/2017/07/crazyflie-based-quadcopter-with-raspberrypi-camera/

---


[![pylint](https://github.com/kamangir/blue-flie/actions/workflows/pylint.yml/badge.svg)](https://github.com/kamangir/blue-flie/actions/workflows/pylint.yml) [![pytest](https://github.com/kamangir/blue-flie/actions/workflows/pytest.yml/badge.svg)](https://github.com/kamangir/blue-flie/actions/workflows/pytest.yml) [![bashtest](https://github.com/kamangir/blue-flie/actions/workflows/bashtest.yml/badge.svg)](https://github.com/kamangir/blue-flie/actions/workflows/bashtest.yml) [![PyPI version](https://img.shields.io/pypi/v/blue-flie.svg)](https://pypi.org/project/blue-flie/) [![PyPI - Downloads](https://img.shields.io/pypi/dd/blue-flie)](https://pypistats.org/packages/blue-flie)

built by 🌀 [`blue_options-4.223.1`](https://github.com/kamangir/awesome-bash-cli), based on 🦋 [`blue_flie-4.5.1`](https://github.com/kamangir/blue-flie).
